# usethis

Automate Python project setup and development tasks that are otherwise performed manually.

usethis knows about popular Python tools, workflows and frameworks, and knows how they
interact. It can add and remove tools, configure them, and set up the project for you
in a way that won't break your existing configuration and it will make the necessary
adjustments to your project configuration files.

usethis gives detailed messages about what it is doing (and what you need to do next).

- Output beginning with `✔` represents a task which usethis has automated.
- Output beginning with `☐` represents a task which you need to perform manually.
- Output beginning with `ℹ` gives hints and tips.

Inspired by an [**R** package of the same name](https://usethis.r-lib.org/index.html),
this package brings a similar experience to the Python ecosystem as a CLI tool.

See the [README.md file](https://github.com/nathanjmcdougall/usethis-python/blob/main/README.md) for more information.
